import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:syncrow_web/pages/access_management/booking_system/bloc/sidebar/sidebar_bloc.dart';
import 'package:syncrow_web/pages/access_management/booking_system/bloc/sidebar/sidebar_event.dart';
import 'package:syncrow_web/pages/access_management/booking_system/bloc/sidebar/sidebar_state.dart';
import 'package:syncrow_web/pages/access_management/booking_system/view/widgets/room_list_item.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';

class BookingSidebar extends StatelessWidget {
  final void Function(int) onRoomSelected;

  const BookingSidebar({
    super.key,
    required this.onRoomSelected,
  });

  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (context) => SidebarBloc()..add(LoadRoomsEvent()),
      child: _SidebarContent(onRoomSelected: onRoomSelected),
    );
  }
}

class _SidebarContent extends StatelessWidget {
  final void Function(int) onRoomSelected;

  const _SidebarContent({
    required this.onRoomSelected,
  });

  @override
  Widget build(BuildContext context) {
    final TextEditingController searchController = TextEditingController();

    return Container(
      decoration: BoxDecoration(
        color: ColorsManager.whiteColors,
        boxShadow: [
          BoxShadow(
            color: ColorsManager.blackColor.withOpacity(0.1),
            offset: const Offset(3, 0),
            blurRadius: 6,
            spreadRadius: 0,
          ),
        ],
      ),
      child: BlocBuilder<SidebarBloc, SidebarState>(
        builder: (context, state) {
          return Column(
            children: [
              const _SidebarHeader(title: 'Spaces'),
              Container(
                decoration: BoxDecoration(
                  color: ColorsManager.whiteColors,
                  borderRadius: BorderRadius.circular(8.0),
                  boxShadow: [
                    BoxShadow(
                      color: ColorsManager.blackColor.withOpacity(0.1),
                      offset: const Offset(0, -2),
                      blurRadius: 4,
                      spreadRadius: 0,
                    ),
                    BoxShadow(
                      color: ColorsManager.blackColor.withOpacity(0.1),
                      offset: const Offset(0, 2),
                      blurRadius: 4,
                      spreadRadius: 0,
                    ),
                  ],
                ),
                child: Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Container(
                    child: Padding(
                      padding: const EdgeInsets.symmetric(
                          horizontal: 16.0, vertical: 8.0),
                      child: Container(
                        decoration: BoxDecoration(
                          color: ColorsManager.counterBackgroundColor,
                          borderRadius: BorderRadius.circular(8.0),
                        ),
                        child: TextField(
                          style:
                              Theme.of(context).textTheme.bodyMedium?.copyWith(
                                    color: ColorsManager.blackColor,
                                  ),
                          controller: searchController,
                          onChanged: (value) {
                            context
                                .read<SidebarBloc>()
                                .add(SearchRoomsEvent(value));
                          },
                          decoration: InputDecoration(
                            hintText: 'Search',
                            suffixIcon: Padding(
                              padding: const EdgeInsets.all(8.0),
                              child: SizedBox(
                                width: 20,
                                height: 20,
                                child: SvgPicture.asset(
                                  Assets.searchIconUser,
                                  color: ColorsManager.primaryTextColor,
                                ),
                              ),
                            ),
                            contentPadding: const EdgeInsets.symmetric(
                                vertical: 8, horizontal: 12),
                            border: const OutlineInputBorder(
                                borderSide: BorderSide.none),
                          ),
                        ),
                      ),
                    ),
                  ),
                ),
              ),
              if (state.isLoading)
                const Expanded(
                  child: Center(child: CircularProgressIndicator()),
                )
              else if (state.errorMessage != null)
                Expanded(
                  child: Center(child: Text(state.errorMessage!)),
                )
              else
                Expanded(
                  child: ListView.builder(
                    itemCount: state.displayedRooms.length,
                    itemBuilder: (context, index) {
                      final room = state.displayedRooms[index];
                      return RoomListItem(
                        room: room,
                        isSelected: state.selectedRoomId == room.id,
                        onTap: () {
                          context
                              .read<SidebarBloc>()
                              .add(SelectRoomEvent(room.id));
                          onRoomSelected(room.id);
                        },
                      );
                    },
                  ),
                ),
            ],
          );
        },
      ),
    );
  }
}

class _SidebarHeader extends StatelessWidget {
  final String title;

  const _SidebarHeader({
    required this.title,
  });

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(16.0),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Text(
            title,
            style: Theme.of(context).textTheme.titleLarge?.copyWith(
                  fontWeight: FontWeight.w400,
                  color: ColorsManager.primaryTextColor,
                  fontSize: 20,
                ),
          ),
        ],
      ),
    );
  }
}
